Solar Forecast Arbiter Core documentation
=========================================

The documentation for the core code of the Solar Forecast Arbiter.

Please see `solarforecastarbiter.org <https://solarforecastarbiter.org/>`_
for more information about the Solar Forecast Arbiter project.

.. todo::

   Add directions on how to cite SFA core code. Probably with Zenodo DOI.


.. toctree::
   :maxdepth: 2

   installation
   contributing
   reference-observations
   reference-forecasts
   cost
   api
   cli
   whatsnew/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
